@@ -292,7 +292,9 @@ class Command:
                             if cmd:
                                 cmd.parent = self
                                 self._args = self._args[1:]
-                                return cmd(' '.join(self.args))
+                                a = self.args
+                                k = ['='.join(i) for i in self.kws.items()]
+                                return cmd(' '.join(a+k))
                     except Exception as x:
                         print(f' ! {name} - {cmd} ! {x} ! ')
 
