@@ -24,3 +24,9 @@ def ssh(host, cmd):
     ret, out, err = rem.run(cmd)
     return ret==0, out.strip()
 
+
+def known_hosts():
+    ssh = pybrary.SSH()
+    ssh.hosts.known()
+    return True, ''
+
